@@ -4,7 +4,7 @@ gcontrol<-function(data,zeta=1000,kappa=4,tau2=1,epsilon=0.01,ngib=500,burn=50,i
   deltot <- rep(0,nkdata)
   kdata <- as.matrix(data)
   x <- a <- rep(0,nkdata)
-  z<-.C("gcontrol",kdata=as.double(kdata),nkdata=as.integer(nkdata),
+  z<-.C("gcontrol_c",kdata=as.double(kdata),nkdata=as.integer(nkdata),
         zeta=as.double(zeta),kappa=as.double(kappa),tau2=as.double(tau2),
         epsilon=as.double(epsilon),ngib=as.integer(ngib),burn=as.integer(burn),
         idumR=as.integer(idum),deltot=as.double(deltot),x=as.double(array(x)),A=as.double(a),PACKAGE="gap")
