@@ -7,10 +7,10 @@ pbsize <- function (kp, gamma=4.5, p=0.15, alpha=5e-8, beta=0.2)
 # pi is the pr(Affected|aa)
 {
   z1alpha <- qnorm(1-alpha/2)
-  z1beta <- qnorm(1-beta)
+  zbeta <- qnorm(beta)
   q <- 1-p
   pi <- kp/(gamma*p+q)^2
   lambda <- pi*p*q*(gamma-1)^2/(1-kp)
-  n <- (z1alpha+z1beta)^2/lambda
+  n <- (z1alpha-zbeta)^2/lambda
   n
 }
